#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-binary
version:              0.2.1.1
visibility:           public
id:                   text-binary-0.2.1.1-EkMgbqejkHR8AjaGgwcB03
key:                  text-binary-0.2.1.1-EkMgbqejkHR8AjaGgwcB03
license:              BSD-2-Clause
maintainer:           waszczuk.kuba@gmail.com
author:               Jakub Waszczuk
stability:            provisional
homepage:             https://github.com/kawu/text-binary
synopsis:             Binary instances for text types
description:
    A compatibility layer providing Binary instances for strict
    and lazy text types for versions older than 1.2.1 of
    <https://hackage.haskell.org/package/text>.

category:             Data
abi:                  be47baf02d71f181ce8c34e939e2599f
exposed:              True
exposed-modules:      Data.Text.Binary
import-dirs:          /usr/lib/ghc-8.10.5/site-local/text-binary-0.2.1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/text-binary-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/text-binary-0.2.1.1
hs-libraries:         HStext-binary-0.2.1.1-EkMgbqejkHR8AjaGgwcB03
depends:              base-4.14.2.0 binary-0.8.8.0 text-1.2.4.1
haddock-interfaces:   /usr/share/doc/haskell-text-binary/html/text-binary.haddock
haddock-html:         /usr/share/doc/haskell-text-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

